@@ -65,7 +65,7 @@ is_prefix_op('#') -> numeric;
 is_prefix_op(_) -> false.
 
 check_regexp(String) ->
-    case re:compile(String) of
+    case re:compile(String, [unicode]) of
 	{ok, _Expr} ->
 	    {regexpr, String};
 	{error, {ErrString, Position}} ->
@@ -169,7 +169,7 @@ mfa2s({M,F,A}) ->
     [c2s(M),':',c2s(F),'/',A].
 
 c2s(C) ->
-    [S] = io_lib:format("~p", [C]),
+    [S] = io_lib:format("~tp", [C]),
     list_to_atom(S).
 
 re(variable) -> ['_'];
@@ -201,7 +201,7 @@ name_it(Name) -> Name.
 %%
 %% %CopyrightBegin%
 %%
-%% Copyright Ericsson AB 1996-2015. All Rights Reserved.
+%% Copyright Ericsson AB 1996-2018. All Rights Reserved.
 %%
 %% Licensed under the Apache License, Version 2.0 (the "License");
 %% you may not use this file except in compliance with the License.
@@ -256,8 +256,7 @@ return_error(Line, Message) ->
 yeccpars0(Tokens, Tzr, State, States, Vstack) ->
     try yeccpars1(Tokens, Tzr, State, States, Vstack)
     catch 
-        error: Error ->
-            Stacktrace = erlang:get_stacktrace(),
+        error: Error: Stacktrace ->
             try yecc_error_type(Error, Stacktrace) of
                 Desc ->
                     erlang:raise(error, {yecc_bug, ?CODE_VERSION, Desc},
@@ -351,27 +350,26 @@ yecctoken_location(Token) ->
     end.
 
 -compile({nowarn_unused_function, yecctoken2string/1}).
-yecctoken2string({atom, _, A}) -> io_lib:write(A);
+yecctoken2string({atom, _, A}) -> io_lib:write_atom(A);
 yecctoken2string({integer,_,N}) -> io_lib:write(N);
 yecctoken2string({float,_,F}) -> io_lib:write(F);
 yecctoken2string({char,_,C}) -> io_lib:write_char(C);
 yecctoken2string({var,_,V}) -> io_lib:format("~s", [V]);
 yecctoken2string({string,_,S}) -> io_lib:write_string(S);
 yecctoken2string({reserved_symbol, _, A}) -> io_lib:write(A);
-yecctoken2string({_Cat, _, Val}) -> io_lib:format("~p",[Val]);
+yecctoken2string({_Cat, _, Val}) -> io_lib:format("~tp", [Val]);
 yecctoken2string({dot, _}) -> "'.'";
-yecctoken2string({'$end', _}) ->
-    [];
+yecctoken2string({'$end', _}) -> [];
 yecctoken2string({Other, _}) when is_atom(Other) ->
-    io_lib:write(Other);
+    io_lib:write_atom(Other);
 yecctoken2string(Other) ->
-    io_lib:write(Other).
+    io_lib:format("~tp", [Other]).
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
 
--file("xref_parser.erl", 374).
+-file("xref_parser.erl", 372).
 
 -dialyzer({nowarn_function, yeccpars2/7}).
 yeccpars2(0=S, Cat, Ss, Stack, T, Ts, Tzr) ->
@@ -573,28 +571,28 @@ yeccpars2_2(S, ':=', Ss, Stack, T, Ts, Tzr) ->
 yeccpars2_2(S, '=', Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 78, Ss, Stack, T, Ts, Tzr);
 yeccpars2_2(_S, '$end', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_2_$end'(Stack),
+ NewStack = 'yeccpars2_2_\'$end\''(Stack),
  yeccgoto_expr(hd(Ss), '$end', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_2(_S, '*', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_2_*'(Stack),
+ NewStack = 'yeccpars2_2_\'*\''(Stack),
  yeccgoto_expr(hd(Ss), '*', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_2(_S, '+', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_2_+'(Stack),
+ NewStack = 'yeccpars2_2_\'+\''(Stack),
  yeccgoto_expr(hd(Ss), '+', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_2(_S, '-', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_2_-'(Stack),
+ NewStack = 'yeccpars2_2_\'-\''(Stack),
  yeccgoto_expr(hd(Ss), '-', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_2(_S, 'of', Ss, Stack, T, Ts, Tzr) ->
- NewStack = yeccpars2_2_of(Stack),
+ NewStack = 'yeccpars2_2_\'of\''(Stack),
  yeccgoto_expr(hd(Ss), 'of', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_2(_S, '|', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_2_|'(Stack),
+ NewStack = 'yeccpars2_2_\'|\''(Stack),
  yeccgoto_expr(hd(Ss), '|', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_2(_S, '||', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_2_||'(Stack),
+ NewStack = 'yeccpars2_2_\'||\''(Stack),
  yeccgoto_expr(hd(Ss), '||', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_2(_S, '|||', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_2_|||'(Stack),
+ NewStack = 'yeccpars2_2_\'|||\''(Stack),
  yeccgoto_expr(hd(Ss), '|||', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_2(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_2_(Stack),
@@ -615,34 +613,34 @@ yeccpars2_5(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccpars2_6(S, decl, Ss, Stack, T, Ts, Tzr) ->
  yeccpars1(S, 33, Ss, Stack, T, Ts, Tzr);
 yeccpars2_6(_S, '$end', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_6_$end'(Stack),
+ NewStack = 'yeccpars2_6_\'$end\''(Stack),
  yeccpars2_73(_S, '$end', [6 | Ss], NewStack, T, Ts, Tzr);
 yeccpars2_6(_S, ')', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_6_)'(Stack),
+ NewStack = 'yeccpars2_6_\')\''(Stack),
  yeccpars2_73(_S, ')', [6 | Ss], NewStack, T, Ts, Tzr);
 yeccpars2_6(_S, '*', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_6_*'(Stack),
+ NewStack = 'yeccpars2_6_\'*\''(Stack),
  yeccpars2_73(_S, '*', [6 | Ss], NewStack, T, Ts, Tzr);
 yeccpars2_6(_S, '+', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_6_+'(Stack),
+ NewStack = 'yeccpars2_6_\'+\''(Stack),
  yeccpars2_73(_S, '+', [6 | Ss], NewStack, T, Ts, Tzr);
 yeccpars2_6(_S, ',', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_6_,'(Stack),
+ NewStack = 'yeccpars2_6_\',\''(Stack),
  yeccpars2_73(_S, ',', [6 | Ss], NewStack, T, Ts, Tzr);
 yeccpars2_6(_S, '-', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_6_-'(Stack),
+ NewStack = 'yeccpars2_6_\'-\''(Stack),
  yeccpars2_73(_S, '-', [6 | Ss], NewStack, T, Ts, Tzr);
 yeccpars2_6(_S, 'of', Ss, Stack, T, Ts, Tzr) ->
- NewStack = yeccpars2_6_of(Stack),
+ NewStack = 'yeccpars2_6_\'of\''(Stack),
  yeccpars2_73(_S, 'of', [6 | Ss], NewStack, T, Ts, Tzr);
 yeccpars2_6(_S, '|', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_6_|'(Stack),
+ NewStack = 'yeccpars2_6_\'|\''(Stack),
  yeccpars2_73(_S, '|', [6 | Ss], NewStack, T, Ts, Tzr);
 yeccpars2_6(_S, '||', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_6_||'(Stack),
+ NewStack = 'yeccpars2_6_\'||\''(Stack),
  yeccpars2_73(_S, '||', [6 | Ss], NewStack, T, Ts, Tzr);
 yeccpars2_6(_S, '|||', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_6_|||'(Stack),
+ NewStack = 'yeccpars2_6_\'|||\''(Stack),
  yeccpars2_73(_S, '|||', [6 | Ss], NewStack, T, Ts, Tzr);
 yeccpars2_6(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccgoto_regatom(hd(Ss), Cat, Ss, Stack, T, Ts, Tzr).
@@ -677,37 +675,37 @@ yeccpars2_10(_S, vertex, Ss, Stack, T, Ts, Tzr) ->
 yeccpars2_10(_S, '{', Ss, Stack, T, Ts, Tzr) ->
  yeccgoto_prefix_op(hd(Ss), '{', Ss, Stack, T, Ts, Tzr);
 yeccpars2_10(_S, '$end', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_10_$end'(Stack),
+ NewStack = 'yeccpars2_10_\'$end\''(Stack),
  yeccgoto_const(hd(Ss), '$end', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_10(_S, ')', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_10_)'(Stack),
+ NewStack = 'yeccpars2_10_\')\''(Stack),
  yeccgoto_const(hd(Ss), ')', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_10(_S, '*', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_10_*'(Stack),
+ NewStack = 'yeccpars2_10_\'*\''(Stack),
  yeccgoto_const(hd(Ss), '*', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_10(_S, '+', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_10_+'(Stack),
+ NewStack = 'yeccpars2_10_\'+\''(Stack),
  yeccgoto_const(hd(Ss), '+', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_10(_S, ',', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_10_,'(Stack),
+ NewStack = 'yeccpars2_10_\',\''(Stack),
  yeccgoto_const(hd(Ss), ',', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_10(_S, '-', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_10_-'(Stack),
+ NewStack = 'yeccpars2_10_\'-\''(Stack),
  yeccgoto_const(hd(Ss), '-', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_10(_S, decl, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_10_decl(Stack),
  yeccgoto_const(hd(Ss), decl, Ss, NewStack, T, Ts, Tzr);
 yeccpars2_10(_S, 'of', Ss, Stack, T, Ts, Tzr) ->
- NewStack = yeccpars2_10_of(Stack),
+ NewStack = 'yeccpars2_10_\'of\''(Stack),
  yeccgoto_const(hd(Ss), 'of', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_10(_S, '|', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_10_|'(Stack),
+ NewStack = 'yeccpars2_10_\'|\''(Stack),
  yeccgoto_const(hd(Ss), '|', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_10(_S, '||', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_10_||'(Stack),
+ NewStack = 'yeccpars2_10_\'||\''(Stack),
  yeccgoto_const(hd(Ss), '||', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_10(_S, '|||', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_10_|||'(Stack),
+ NewStack = 'yeccpars2_10_\'|||\''(Stack),
  yeccgoto_const(hd(Ss), '|||', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_10(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_10_(Stack),
@@ -867,34 +865,34 @@ yeccpars2_37(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccgoto_expr(hd(Nss), Cat, Nss, NewStack, T, Ts, Tzr).
 
 yeccpars2_38(_S, '$end', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_38_$end'(Stack),
+ NewStack = 'yeccpars2_38_\'$end\''(Stack),
  yeccgoto_expr(hd(Ss), '$end', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_38(_S, ')', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_38_)'(Stack),
+ NewStack = 'yeccpars2_38_\')\''(Stack),
  yeccgoto_expr(hd(Ss), ')', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_38(_S, '*', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_38_*'(Stack),
+ NewStack = 'yeccpars2_38_\'*\''(Stack),
  yeccgoto_expr(hd(Ss), '*', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_38(_S, '+', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_38_+'(Stack),
+ NewStack = 'yeccpars2_38_\'+\''(Stack),
  yeccgoto_expr(hd(Ss), '+', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_38(_S, ',', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_38_,'(Stack),
+ NewStack = 'yeccpars2_38_\',\''(Stack),
  yeccgoto_expr(hd(Ss), ',', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_38(_S, '-', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_38_-'(Stack),
+ NewStack = 'yeccpars2_38_\'-\''(Stack),
  yeccgoto_expr(hd(Ss), '-', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_38(_S, 'of', Ss, Stack, T, Ts, Tzr) ->
- NewStack = yeccpars2_38_of(Stack),
+ NewStack = 'yeccpars2_38_\'of\''(Stack),
  yeccgoto_expr(hd(Ss), 'of', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_38(_S, '|', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_38_|'(Stack),
+ NewStack = 'yeccpars2_38_\'|\''(Stack),
  yeccgoto_expr(hd(Ss), '|', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_38(_S, '||', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_38_||'(Stack),
+ NewStack = 'yeccpars2_38_\'||\''(Stack),
  yeccgoto_expr(hd(Ss), '||', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_38(_S, '|||', Ss, Stack, T, Ts, Tzr) ->
- NewStack = 'yeccpars2_38_|||'(Stack),
+ NewStack = 'yeccpars2_38_\'|||\''(Stack),
  yeccgoto_expr(hd(Ss), '|||', Ss, NewStack, T, Ts, Tzr);
 yeccpars2_38(_S, Cat, Ss, Stack, T, Ts, Tzr) ->
  NewStack = yeccpars2_38_(Stack),
@@ -1583,65 +1581,65 @@ yeccgoto_variable(76=_S, Cat, Ss, Stack, T, Ts, Tzr) ->
 yeccgoto_xref(0, Cat, Ss, Stack, T, Ts, Tzr) ->
  yeccpars2_1(1, Cat, Ss, Stack, T, Ts, Tzr).
 
--compile({inline,'yeccpars2_2_$end'/1}).
+-compile({inline,'yeccpars2_2_\'$end\''/1}).
 -file("xref_parser.yrl", 63).
-'yeccpars2_2_$end'(__Stack0) ->
+'yeccpars2_2_\'$end\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { variable , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_2_*'/1}).
+-compile({inline,'yeccpars2_2_\'*\''/1}).
 -file("xref_parser.yrl", 63).
-'yeccpars2_2_*'(__Stack0) ->
+'yeccpars2_2_\'*\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { variable , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_2_+'/1}).
+-compile({inline,'yeccpars2_2_\'+\''/1}).
 -file("xref_parser.yrl", 63).
-'yeccpars2_2_+'(__Stack0) ->
+'yeccpars2_2_\'+\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { variable , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_2_-'/1}).
+-compile({inline,'yeccpars2_2_\'-\''/1}).
 -file("xref_parser.yrl", 63).
-'yeccpars2_2_-'(__Stack0) ->
+'yeccpars2_2_\'-\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { variable , __1 }
   end | __Stack].
 
--compile({inline,yeccpars2_2_of/1}).
+-compile({inline,'yeccpars2_2_\'of\''/1}).
 -file("xref_parser.yrl", 63).
-yeccpars2_2_of(__Stack0) ->
+'yeccpars2_2_\'of\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { variable , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_2_|'/1}).
+-compile({inline,'yeccpars2_2_\'|\''/1}).
 -file("xref_parser.yrl", 63).
-'yeccpars2_2_|'(__Stack0) ->
+'yeccpars2_2_\'|\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { variable , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_2_||'/1}).
+-compile({inline,'yeccpars2_2_\'||\''/1}).
 -file("xref_parser.yrl", 63).
-'yeccpars2_2_||'(__Stack0) ->
+'yeccpars2_2_\'||\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { variable , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_2_|||'/1}).
+-compile({inline,'yeccpars2_2_\'|||\''/1}).
 -file("xref_parser.yrl", 63).
-'yeccpars2_2_|||'(__Stack0) ->
+'yeccpars2_2_\'|||\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { variable , __1 }
@@ -1663,119 +1661,119 @@ yeccpars2_4_(__Stack0) ->
    [ __1 ]
   end | __Stack].
 
--compile({inline,'yeccpars2_6_$end'/1}).
+-compile({inline,'yeccpars2_6_\'$end\''/1}).
 -file("xref_parser.yrl", 102).
-'yeccpars2_6_$end'(__Stack0) ->
+'yeccpars2_6_\'$end\''(__Stack0) ->
  [begin
    unknown
   end | __Stack0].
 
--compile({inline,'yeccpars2_6_)'/1}).
+-compile({inline,'yeccpars2_6_\')\''/1}).
 -file("xref_parser.yrl", 102).
-'yeccpars2_6_)'(__Stack0) ->
+'yeccpars2_6_\')\''(__Stack0) ->
  [begin
    unknown
   end | __Stack0].
 
--compile({inline,'yeccpars2_6_*'/1}).
+-compile({inline,'yeccpars2_6_\'*\''/1}).
 -file("xref_parser.yrl", 102).
-'yeccpars2_6_*'(__Stack0) ->
+'yeccpars2_6_\'*\''(__Stack0) ->
  [begin
    unknown
   end | __Stack0].
 
--compile({inline,'yeccpars2_6_+'/1}).
+-compile({inline,'yeccpars2_6_\'+\''/1}).
 -file("xref_parser.yrl", 102).
-'yeccpars2_6_+'(__Stack0) ->
+'yeccpars2_6_\'+\''(__Stack0) ->
  [begin
    unknown
   end | __Stack0].
 
--compile({inline,'yeccpars2_6_,'/1}).
+-compile({inline,'yeccpars2_6_\',\''/1}).
 -file("xref_parser.yrl", 102).
-'yeccpars2_6_,'(__Stack0) ->
+'yeccpars2_6_\',\''(__Stack0) ->
  [begin
    unknown
   end | __Stack0].
 
--compile({inline,'yeccpars2_6_-'/1}).
+-compile({inline,'yeccpars2_6_\'-\''/1}).
 -file("xref_parser.yrl", 102).
-'yeccpars2_6_-'(__Stack0) ->
+'yeccpars2_6_\'-\''(__Stack0) ->
  [begin
    unknown
   end | __Stack0].
 
--compile({inline,yeccpars2_6_of/1}).
+-compile({inline,'yeccpars2_6_\'of\''/1}).
 -file("xref_parser.yrl", 102).
-yeccpars2_6_of(__Stack0) ->
+'yeccpars2_6_\'of\''(__Stack0) ->
  [begin
    unknown
   end | __Stack0].
 
--compile({inline,'yeccpars2_6_|'/1}).
+-compile({inline,'yeccpars2_6_\'|\''/1}).
 -file("xref_parser.yrl", 102).
-'yeccpars2_6_|'(__Stack0) ->
+'yeccpars2_6_\'|\''(__Stack0) ->
  [begin
    unknown
   end | __Stack0].
 
--compile({inline,'yeccpars2_6_||'/1}).
+-compile({inline,'yeccpars2_6_\'||\''/1}).
 -file("xref_parser.yrl", 102).
-'yeccpars2_6_||'(__Stack0) ->
+'yeccpars2_6_\'||\''(__Stack0) ->
  [begin
    unknown
   end | __Stack0].
 
--compile({inline,'yeccpars2_6_|||'/1}).
+-compile({inline,'yeccpars2_6_\'|||\''/1}).
 -file("xref_parser.yrl", 102).
-'yeccpars2_6_|||'(__Stack0) ->
+'yeccpars2_6_\'|||\''(__Stack0) ->
  [begin
    unknown
   end | __Stack0].
 
--compile({inline,'yeccpars2_10_$end'/1}).
+-compile({inline,'yeccpars2_10_\'$end\''/1}).
 -file("xref_parser.yrl", 79).
-'yeccpars2_10_$end'(__Stack0) ->
+'yeccpars2_10_\'$end\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { constant , unknown , vertex , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_10_)'/1}).
+-compile({inline,'yeccpars2_10_\')\''/1}).
 -file("xref_parser.yrl", 79).
-'yeccpars2_10_)'(__Stack0) ->
+'yeccpars2_10_\')\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { constant , unknown , vertex , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_10_*'/1}).
+-compile({inline,'yeccpars2_10_\'*\''/1}).
 -file("xref_parser.yrl", 79).
-'yeccpars2_10_*'(__Stack0) ->
+'yeccpars2_10_\'*\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { constant , unknown , vertex , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_10_+'/1}).
+-compile({inline,'yeccpars2_10_\'+\''/1}).
 -file("xref_parser.yrl", 79).
-'yeccpars2_10_+'(__Stack0) ->
+'yeccpars2_10_\'+\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { constant , unknown , vertex , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_10_,'/1}).
+-compile({inline,'yeccpars2_10_\',\''/1}).
 -file("xref_parser.yrl", 79).
-'yeccpars2_10_,'(__Stack0) ->
+'yeccpars2_10_\',\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { constant , unknown , vertex , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_10_-'/1}).
+-compile({inline,'yeccpars2_10_\'-\''/1}).
 -file("xref_parser.yrl", 79).
-'yeccpars2_10_-'(__Stack0) ->
+'yeccpars2_10_\'-\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { constant , unknown , vertex , __1 }
@@ -1789,33 +1787,33 @@ yeccpars2_10_decl(__Stack0) ->
    { constant , unknown , vertex , __1 }
   end | __Stack].
 
--compile({inline,yeccpars2_10_of/1}).
+-compile({inline,'yeccpars2_10_\'of\''/1}).
 -file("xref_parser.yrl", 79).
-yeccpars2_10_of(__Stack0) ->
+'yeccpars2_10_\'of\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { constant , unknown , vertex , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_10_|'/1}).
+-compile({inline,'yeccpars2_10_\'|\''/1}).
 -file("xref_parser.yrl", 79).
-'yeccpars2_10_|'(__Stack0) ->
+'yeccpars2_10_\'|\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { constant , unknown , vertex , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_10_||'/1}).
+-compile({inline,'yeccpars2_10_\'||\''/1}).
 -file("xref_parser.yrl", 79).
-'yeccpars2_10_||'(__Stack0) ->
+'yeccpars2_10_\'||\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { constant , unknown , vertex , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_10_|||'/1}).
+-compile({inline,'yeccpars2_10_\'|||\''/1}).
 -file("xref_parser.yrl", 79).
-'yeccpars2_10_|||'(__Stack0) ->
+'yeccpars2_10_\'|||\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { constant , unknown , vertex , __1 }
@@ -1967,81 +1965,81 @@ yeccpars2_37_(__Stack0) ->
    type ( { list , [ __2 | __3 ] } , __5 )
   end | __Stack].
 
--compile({inline,'yeccpars2_38_$end'/1}).
+-compile({inline,'yeccpars2_38_\'$end\''/1}).
 -file("xref_parser.yrl", 63).
-'yeccpars2_38_$end'(__Stack0) ->
+'yeccpars2_38_\'$end\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { variable , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_38_)'/1}).
+-compile({inline,'yeccpars2_38_\')\''/1}).
 -file("xref_parser.yrl", 63).
-'yeccpars2_38_)'(__Stack0) ->
+'yeccpars2_38_\')\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { variable , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_38_*'/1}).
+-compile({inline,'yeccpars2_38_\'*\''/1}).
 -file("xref_parser.yrl", 63).
-'yeccpars2_38_*'(__Stack0) ->
+'yeccpars2_38_\'*\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { variable , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_38_+'/1}).
+-compile({inline,'yeccpars2_38_\'+\''/1}).
 -file("xref_parser.yrl", 63).
-'yeccpars2_38_+'(__Stack0) ->
+'yeccpars2_38_\'+\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { variable , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_38_,'/1}).
+-compile({inline,'yeccpars2_38_\',\''/1}).
 -file("xref_parser.yrl", 63).
-'yeccpars2_38_,'(__Stack0) ->
+'yeccpars2_38_\',\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { variable , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_38_-'/1}).
+-compile({inline,'yeccpars2_38_\'-\''/1}).
 -file("xref_parser.yrl", 63).
-'yeccpars2_38_-'(__Stack0) ->
+'yeccpars2_38_\'-\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { variable , __1 }
   end | __Stack].
 
--compile({inline,yeccpars2_38_of/1}).
+-compile({inline,'yeccpars2_38_\'of\''/1}).
 -file("xref_parser.yrl", 63).
-yeccpars2_38_of(__Stack0) ->
+'yeccpars2_38_\'of\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { variable , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_38_|'/1}).
+-compile({inline,'yeccpars2_38_\'|\''/1}).
 -file("xref_parser.yrl", 63).
-'yeccpars2_38_|'(__Stack0) ->
+'yeccpars2_38_\'|\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { variable , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_38_||'/1}).
+-compile({inline,'yeccpars2_38_\'||\''/1}).
 -file("xref_parser.yrl", 63).
-'yeccpars2_38_||'(__Stack0) ->
+'yeccpars2_38_\'||\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { variable , __1 }
   end | __Stack].
 
--compile({inline,'yeccpars2_38_|||'/1}).
+-compile({inline,'yeccpars2_38_\'|||\''/1}).
 -file("xref_parser.yrl", 63).
-'yeccpars2_38_|||'(__Stack0) ->
+'yeccpars2_38_\'|||\''(__Stack0) ->
  [__1 | __Stack] = __Stack0,
  [begin
    { variable , __1 }
